@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@ from tencentcloud.antiddos.v20200309 import models
 
 class AntiddosClient(AbstractClient):
     _apiVersion = '2020-03-09'
-    _endpoint = 'antiddos.tencentcloudapi.com'
+    _endpoint = 'antiddos.intl.tencentcloudapi.com'
     _service = 'antiddos'
 
 
@@ -808,31 +808,6 @@ class AntiddosClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def DescribeBlackWhiteIpList(self, request):
-        """接口变更
-
-        This API is used to get an Anti-DDoS IP blocklist/allowlist.
-
-        :param request: Request instance for DescribeBlackWhiteIpList.
-        :type request: :class:`tencentcloud.antiddos.v20200309.models.DescribeBlackWhiteIpListRequest`
-        :rtype: :class:`tencentcloud.antiddos.v20200309.models.DescribeBlackWhiteIpListResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DescribeBlackWhiteIpList", params, headers=headers)
-            response = json.loads(body)
-            model = models.DescribeBlackWhiteIpListResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
     def DescribeCCLevelList(self, request):
         """Gets the list of CC protection levels
 
@@ -1293,31 +1268,6 @@ class AntiddosClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def DescribeListProtectThresholdConfig(self, request):
-        """接口变更
-
-        This API is used to get a list of protection threshold configurations for AI protection switch, protection level, and CC threshold switch.
-
-        :param request: Request instance for DescribeListProtectThresholdConfig.
-        :type request: :class:`tencentcloud.antiddos.v20200309.models.DescribeListProtectThresholdConfigRequest`
-        :rtype: :class:`tencentcloud.antiddos.v20200309.models.DescribeListProtectThresholdConfigResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DescribeListProtectThresholdConfig", params, headers=headers)
-            response = json.loads(body)
-            model = models.DescribeListProtectThresholdConfigResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
     def DescribeListProtocolBlockConfig(self, request):
         """This API is used to get a list of Anti-DDoS protocol blocking configurations.
 
