@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@ from tencentcloud.chdfs.v20201112 import models
 
 class ChdfsClient(AbstractClient):
     _apiVersion = '2020-11-12'
-    _endpoint = 'chdfs.tencentcloudapi.com'
+    _endpoint = 'chdfs.intl.tencentcloudapi.com'
     _service = 'chdfs'
 
 
