@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@ from tencentcloud.cvm.v20170312 import models
 
 class CvmClient(AbstractClient):
     _apiVersion = '2017-03-12'
-    _endpoint = 'cvm.tencentcloudapi.com'
+    _endpoint = 'cvm.intl.tencentcloudapi.com'
     _service = 'cvm'
 
 
@@ -244,6 +244,33 @@ class CvmClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateLaunchTemplate(self, request):
+        """This interface (CreateLaunchTemplate) is used for instance launch template creation.
+
+        An instance launch template is a configuration data and can be used to create instances. Its content includes configurations required to create instances, such as instance type, types and sizes of data disk and system disk, and security group and other information.
+
+        This API is used to create an instance launch template. After the initial creation of the instance template, its template version is the default version 1. A new version can be created using CreateLaunchTemplateVersion (https://intl.cloud.tencent.com/document/product/213/66326?from_cn_redirect=1), and the version number will increment. By default, when specifying an instance launch template in RunInstances (https://intl.cloud.tencent.com/document/product/213/15730?from_cn_redirect=1), if the template version number is not specified, the default version will be used.
+
+        :param request: Request instance for CreateLaunchTemplate.
+        :type request: :class:`tencentcloud.cvm.v20170312.models.CreateLaunchTemplateRequest`
+        :rtype: :class:`tencentcloud.cvm.v20170312.models.CreateLaunchTemplateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateLaunchTemplate", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateLaunchTemplateResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateLaunchTemplateVersion(self, request):
         """This API is used to create an instance launch template based on the specified template ID and the corresponding template version number. The default version number will be used when no template version numbers are specified. Each instance launch template can have up to 30 version numbers.
 
@@ -674,6 +701,29 @@ class CvmClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeInstancesAttributes(self, request):
+        """This API is used to obtain the attributes of specified instances. Currently, it supports querying the custom data UserData of instances.
+
+        :param request: Request instance for DescribeInstancesAttributes.
+        :type request: :class:`tencentcloud.cvm.v20170312.models.DescribeInstancesAttributesRequest`
+        :rtype: :class:`tencentcloud.cvm.v20170312.models.DescribeInstancesAttributesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeInstancesAttributes", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeInstancesAttributesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeInstancesOperationLimit(self, request):
         """This API is used to query limitations on operations on an instance.
 
@@ -842,8 +892,31 @@ class CvmClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeReservedInstances(self, request):
+        """This API is used to list the reserved instances purchased by the user.
+
+        :param request: Request instance for DescribeReservedInstances.
+        :type request: :class:`tencentcloud.cvm.v20170312.models.DescribeReservedInstancesRequest`
+        :rtype: :class:`tencentcloud.cvm.v20170312.models.DescribeReservedInstancesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeReservedInstances", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeReservedInstancesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeReservedInstancesConfigInfos(self, request):
-        """This API is used to describe reserved instance (RI) offerings. Currently, RIs are only offered to beta users.
+        """This API is used to describe reserved instance (RI) offerings.
 
         :param request: Request instance for DescribeReservedInstancesConfigInfos.
         :type request: :class:`tencentcloud.cvm.v20170312.models.DescribeReservedInstancesConfigInfosRequest`
@@ -1434,6 +1507,32 @@ class CvmClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyInstancesRenewFlag(self, request):
+        """This API is used to modify the renewal flag of monthly subscription instances.
+
+        * After an instance is marked as auto-renewal, it will be automatically renewed for one month each time it expires.
+        * Batch operations are supported. The maximum number of instances for each request is 100.* You can query the result of the instance operation by calling the API [DescribeInstances](https://intl.cloud.tencent.com/document/api/213/15728?from_cn_redirect=1#.E7.A4.BA.E4.BE.8B3-.E6.9F.A5.E8.AF.A2.E5.AE.9E.E4.BE.8B.E7.9A.84.E6.9C.80.E6.96.B0.E6.93.8D.E4.BD.9C.E6.83.85.E5.86.B5). If the latest operation status (LatestOperationState) of the instance is **SUCCESS**, the operation is successful.
+
+        :param request: Request instance for ModifyInstancesRenewFlag.
+        :type request: :class:`tencentcloud.cvm.v20170312.models.ModifyInstancesRenewFlagRequest`
+        :rtype: :class:`tencentcloud.cvm.v20170312.models.ModifyInstancesRenewFlagResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyInstancesRenewFlag", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyInstancesRenewFlagResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyInstancesVpcAttribute(self, request):
         """This API is used to modify the VPC attributes of an instance, such as the VPC IP address.
         * This action will shut down the instance, and restart it after the modification is completed.
@@ -1861,7 +1960,6 @@ class CvmClient(AbstractClient):
 
         * Use this API to return instances that are no longer required.
         * Pay-as-you-go instances can be returned directly through this API.
-        * When this API is called for the first time, the instance will be moved to the recycle bin. When this API is called for the second time, the instance will be terminated and cannot be recovered.
         * Batch operations are supported. The allowed maximum number of instances in each request is 100.
 
         :param request: Request instance for TerminateInstances.
