@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -44,6 +44,9 @@ FAILEDOPERATION_STARTJOBFAILED = 'FailedOperation.StartJobFailed'
 # This operation cannot be performed due to a status conflict.
 FAILEDOPERATION_STATUSINCONFLICT = 'FailedOperation.StatusInConflict'
 
+# 
+FAILEDOPERATION_USERNOTAUTHED = 'FailedOperation.UserNotAuthed'
+
 # An internal error occurred.
 INTERNALERROR = 'InternalError'
 
@@ -62,6 +65,9 @@ INTERNALERROR_DATABASEERROR = 'InternalError.DatabaseError'
 # Migration tasks are in conflict.
 INTERNALERROR_DUPLICATEJOB = 'InternalError.DuplicateJob'
 
+# HTTP request error.
+INTERNALERROR_EXECHTTPREQUESTERROR = 'InternalError.ExecHttpRequestError'
+
 # An internal error occurred.
 INTERNALERROR_INTERNALERRORERROR = 'InternalError.InternalErrorError'
 
@@ -137,6 +143,9 @@ OPERATIONDENIED_JOBOPERATIONDENIEDERROR = 'OperationDenied.JobOperationDeniedErr
 # The account balance is insufficient.
 OPERATIONDENIED_NOTENOUGHMONEYERROR = 'OperationDenied.NotEnoughMoneyError'
 
+# This operation cannot be performed.
+OPERATIONDENIED_OPERATIONDENIED = 'OperationDenied.OperationDenied'
+
 # The operation was denied.
 OPERATIONDENIED_OPERATIONDENIEDERROR = 'OperationDenied.OperationDeniedError'
 
