@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,12 +22,12 @@ from tencentcloud.kms.v20190118 import models
 
 class KmsClient(AbstractClient):
     _apiVersion = '2019-01-18'
-    _endpoint = 'kms.tencentcloudapi.com'
+    _endpoint = 'kms.intl.tencentcloudapi.com'
     _service = 'kms'
 
 
     def ArchiveKey(self, request):
-        """This API is used to archive keys. The archived keys can only be used for decryption but not encryption.
+        """This API is used to archive keys.The archived keys can only be used for decryption but not encryption.
 
         :param request: Request instance for ArchiveKey.
         :type request: :class:`tencentcloud.kms.v20190118.models.ArchiveKeyRequest`
