@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@ from tencentcloud.lcic.v20220817 import models
 
 class LcicClient(AbstractClient):
     _apiVersion = '2022-08-17'
-    _endpoint = 'lcic.tencentcloudapi.com'
+    _endpoint = 'lcic.intl.tencentcloudapi.com'
     _service = 'lcic'
 
 
@@ -617,9 +617,7 @@ class LcicClient(AbstractClient):
 
 
     def DescribeDocuments(self, request):
-        """有新接口替换
-
-        A new API is offered for this action now.
+        """A new API is offered for this action now.
 
         This API is used to query courseware. It has been deprecated. Please use `BatchDescribeDocument` instead.
 
