@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -26,6 +26,9 @@ FAILEDOPERATION_EMPTYIMAGEERROR = 'FailedOperation.EmptyImageError'
 # Recognition by the engine timed out.
 FAILEDOPERATION_ENGINERECOGNIZETIMEOUT = 'FailedOperation.EngineRecognizeTimeout'
 
+# 
+FAILEDOPERATION_FIELDEXCEPTION = 'FailedOperation.FieldException'
+
 # The ID card information (ID number, name, etc.) is invalid.
 FAILEDOPERATION_IDCARDINFOILLEGAL = 'FailedOperation.IdCardInfoIllegal'
 
@@ -53,6 +56,9 @@ FAILEDOPERATION_IMAGENOTEXT = 'FailedOperation.ImageNoText'
 # The image is too large. Please see the description of image size limit in the output parameters.
 FAILEDOPERATION_IMAGESIZETOOLARGE = 'FailedOperation.ImageSizeTooLarge'
 
+# 
+FAILEDOPERATION_INCONSISTENCYBETWEENMRZANDVRZ = 'FailedOperation.InconsistencyBetweenMRZAndVRZ'
+
 # The input language is not supported.
 FAILEDOPERATION_LANGUAGENOTSUPPORT = 'FailedOperation.LanguageNotSupport'
 
@@ -71,7 +77,7 @@ FAILEDOPERATION_NOMASIDCARD = 'FailedOperation.NoMASIDCard'
 # Not a passport.
 FAILEDOPERATION_NOPASSPORT = 'FailedOperation.NoPassport'
 
-# OCR failed.
+# OCR failed. This error may be caused by unstable network connections,service anomalies or other issues.
 FAILEDOPERATION_OCRFAILED = 'FailedOperation.OcrFailed'
 
 # Unknown error.
@@ -80,7 +86,7 @@ FAILEDOPERATION_UNKNOWERROR = 'FailedOperation.UnKnowError'
 # The service is not activated.
 FAILEDOPERATION_UNOPENERROR = 'FailedOperation.UnOpenError'
 
-# 
+# Warning service error.
 FAILEDOPERATION_WARNINGSERVICEFAILED = 'FailedOperation.WarningServiceFailed'
 
 # Config is not in valid JSON format.
@@ -103,3 +109,6 @@ RESOURCEUNAVAILABLE_RESOURCEPACKAGERUNOUT = 'ResourceUnavailable.ResourcePackage
 
 # Exceptional billing status.
 RESOURCESSOLDOUT_CHARGESTATUSEXCEPTION = 'ResourcesSoldOut.ChargeStatusException'
+
+# Unrecognized argument.
+UNKNOWNPARAMETER = 'UnknownParameter'
