@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,6 +14,12 @@
 # limitations under the License.
 
 
+# Operation failed.
+FAILEDOPERATION = 'FailedOperation'
+
+# The account has been registered.
+FAILEDOPERATION_ACCOUNTALREADYREGISTER = 'FailedOperation.AccountAlreadyRegister'
+
 # The application already exists.
 FAILEDOPERATION_APPLYEXIST = 'FailedOperation.ApplyExist'
 
@@ -26,6 +32,21 @@ FAILEDOPERATION_AUTHINFONOTSAME = 'FailedOperation.AuthInfoNotSame'
 # The user has not completed enterprise identity verification.
 FAILEDOPERATION_AUTHNOTENTERPRISE = 'FailedOperation.AuthNotEnterprise'
 
+# The mailbox binding link has expired.
+FAILEDOPERATION_BINDEMAILLINKEXPIRED = 'FailedOperation.BindEmailLinkExpired'
+
+# The mailbox binding link is invalid.
+FAILEDOPERATION_BINDEMAILLINKINVALID = 'FailedOperation.BindEmailLinkInvalid'
+
+# Member permission change record exists.
+FAILEDOPERATION_CHANGEPERMISSIONRECORDEXIST = 'FailedOperation.ChangePermissionRecordExist'
+
+# Failed to check the mobile phone binding capacity limit.
+FAILEDOPERATION_CHECKACCOUNTPHONEBINDLIMIT = 'FailedOperation.CheckAccountPhoneBindLimit'
+
+# Failed to check the mailbox binding status.
+FAILEDOPERATION_CHECKMAILACCOUNT = 'FailedOperation.CheckMailAccount'
+
 # Permission configurations created for a directory exceed the upper limit.
 FAILEDOPERATION_CONFIGURATIONOVERUPPERLIMIT = 'FailedOperation.ConfigurationOverUpperLimit'
 
@@ -62,27 +83,48 @@ FAILEDOPERATION_DECODEMETADATADOCUMENTFAILED = 'FailedOperation.DecodeMetadataDo
 # The user group still contains users and does not allow deleting users.
 FAILEDOPERATION_DELETEGROUPNOTALLOWEXISTUSER = 'FailedOperation.DeleteGroupNotAllowExistUser'
 
+# Exception occurred when deleting the authorization policy.
+FAILEDOPERATION_DELETEPOLICY = 'FailedOperation.DeletePolicy'
+
 # An error occurred in the query of the organization service usage status.
 FAILEDOPERATION_DESCRIBEORGSERVICEUSAGESTATUSERR = 'FailedOperation.DescribeOrgServiceUsageStatusErr'
 
 # You cannot quit an organization created by yourself.
 FAILEDOPERATION_DISABLEQUITSELFCREATEDORGANIZATION = 'FailedOperation.DisableQuitSelfCreatedOrganization'
 
+# The email has been used.
+FAILEDOPERATION_EMAILALREADYUSED = 'FailedOperation.EmailAlreadyUsed'
+
+# Mailbox binding has become invalid.
+FAILEDOPERATION_EMAILBINDRECORDINVALID = 'FailedOperation.EmailBindRecordInvalid'
+
 # There are shared resources with other organization members or from other organization members.
 FAILEDOPERATION_EXISTOTHERORGANIZATIONMEMBERSHARED = 'FailedOperation.ExistOtherOrganizationMemberShared'
 
+# There are shared members not in the organization.
+FAILEDOPERATION_EXISTSHAREMEMBERNOTINORGANIZATION = 'FailedOperation.ExistShareMemberNotInOrganization'
+
 # Errors occurred when account's regional attributes are obtained.
 FAILEDOPERATION_GETACCOUNTREGION = 'FailedOperation.GetAccountRegion'
 
 # An error occurred while querying the identity information.
 FAILEDOPERATION_GETAUTHINFO = 'FailedOperation.GetAuthInfo'
 
+# Failed to query the policy.
+FAILEDOPERATION_GETPOLICYDETAIL = 'FailedOperation.GetPolicyDetail'
+
 # User groups created exceed the upper limit.
 FAILEDOPERATION_GROUPOVERUPPERLIMIT = 'FailedOperation.GroupOverUpperLimit'
 
+# User group type and user type do not match.
+FAILEDOPERATION_GROUPTYPEUSERTYPENOTMATCH = 'FailedOperation.GroupTypeUserTypeNotMatch'
+
 # Members of the CIC user group exceed the limit.
 FAILEDOPERATION_GROUPUSERCOUNTOVERUPPERLIMIT = 'FailedOperation.GroupUserCountOverUpperLimit'
 
+# The shared unit has different shared resource types.
+FAILEDOPERATION_HASDIFFERENTRESOURCETYPE = 'FailedOperation.HasDifferentResourceType'
+
 # The CIC service has been activated.
 FAILEDOPERATION_IDENTITYCENTERALREADYOPEN = 'FailedOperation.IdentityCenterAlreadyOpen'
 
@@ -107,12 +149,36 @@ FAILEDOPERATION_IMPORTFILEILLEGAL = 'FailedOperation.ImportFileIllegal'
 # The invitation already exists.
 FAILEDOPERATION_INVITATIONEXIST = 'FailedOperation.InvitationExist'
 
+# Manually created user groups cannot be deleted.
+FAILEDOPERATION_MANUALGROUPNOTDELETE = 'FailedOperation.ManualGroupNotDelete'
+
+# Manually created user groups cannot be updated.
+FAILEDOPERATION_MANUALGROUPNOTUPDATE = 'FailedOperation.ManualGroupNotUpdate'
+
+# Manually created users cannot be deleted.
+FAILEDOPERATION_MANUALUSERNOTDELETE = 'FailedOperation.ManualUserNotDelete'
+
+# Manually created users cannot be updated.
+FAILEDOPERATION_MANUALUSERNOTUPDATE = 'FailedOperation.ManualUserNotUpdate'
+
+# Mailbox binding failed.
+FAILEDOPERATION_MEMBERBINDEMAILERROR = 'FailedOperation.MemberBindEmailError'
+
+# Verification mobile numbe binding failed.
+FAILEDOPERATION_MEMBERBINDPHONEERROR = 'FailedOperation.MemberBindPhoneError'
+
+# The member has a mailbox.
+FAILEDOPERATION_MEMBEREMAILEXIST = 'FailedOperation.MemberEmailExist'
+
 # The member has a payer and cannot be deleted.
 FAILEDOPERATION_MEMBEREXISTDELEGATEPAYERNOTALLOWDELETE = 'FailedOperation.MemberExistDelegatePayerNotAllowDelete'
 
 # The member already belongs to another organization.
 FAILEDOPERATION_MEMBEREXISTINOTHERORGANIZATION = 'FailedOperation.MemberExistInOtherOrganization'
 
+# Member authorization is in use.
+FAILEDOPERATION_MEMBERIDENTITYAUTHUSED = 'FailedOperation.MemberIdentityAuthUsed'
+
 # The member is a payer and cannot be deleted.
 FAILEDOPERATION_MEMBERISDELEGATEPAYERNOTALLOWDELETE = 'FailedOperation.MemberIsDelegatePayerNotAllowDelete'
 
@@ -146,6 +212,18 @@ FAILEDOPERATION_ORGANIZATIONAUTHMANAGENOTALLOWDELETE = 'FailedOperation.Organiza
 # Real-name authentication relationship already exists.
 FAILEDOPERATION_ORGANIZATIONAUTHRELATIONEXIST = 'FailedOperation.OrganizationAuthRelationExist'
 
+# The organization already exists.
+FAILEDOPERATION_ORGANIZATIONEXISTALREADY = 'FailedOperation.OrganizationExistAlready'
+
+# Organization identity is in use.
+FAILEDOPERATION_ORGANIZATIONIDENTITYINUSED = 'FailedOperation.OrganizationIdentityInUsed'
+
+# Organization identity name is in use.
+FAILEDOPERATION_ORGANIZATIONIDENTITYNAMEUSED = 'FailedOperation.OrganizationIdentityNameUsed'
+
+# Organization identity policy is invalid.
+FAILEDOPERATION_ORGANIZATIONIDENTITYPOLICYERROR = 'FailedOperation.OrganizationIdentityPolicyError'
+
 # Member already exists.
 FAILEDOPERATION_ORGANIZATIONMEMBEREXIST = 'FailedOperation.OrganizationMemberExist'
 
@@ -167,12 +245,18 @@ FAILEDOPERATION_ORGANIZATIONNODENOTEMPTY = 'FailedOperation.OrganizationNodeNotE
 # The organization node does not exist.
 FAILEDOPERATION_ORGANIZATIONNODENOTEXIST = 'FailedOperation.OrganizationNodeNotExist'
 
+# There are members in this organization.
+FAILEDOPERATION_ORGANIZATIONNOTEMPTY = 'FailedOperation.OrganizationNotEmpty'
+
 # The organization permission is invalid.
 FAILEDOPERATION_ORGANIZATIONPERMISSIONILLEGAL = 'FailedOperation.OrganizationPermissionIllegal'
 
 # The organization policy is invalid.
 FAILEDOPERATION_ORGANIZATIONPOLICYILLEGAL = 'FailedOperation.OrganizationPolicyIllegal'
 
+# Group policy is not disabled.
+FAILEDOPERATION_ORGANIZATIONPOLICYISNOTDISABLED = 'FailedOperation.OrganizationPolicyIsNotDisabled'
+
 # Organization service delegation is in use.
 FAILEDOPERATION_ORGANIZATIONSERVICEASSIGNISUSE = 'FailedOperation.OrganizationServiceAssignIsUse'
 
@@ -182,12 +266,21 @@ FAILEDOPERATION_PARTNERMANAGEMENTERR = 'FailedOperation.PartnerManagementErr'
 # The payer is invalid.
 FAILEDOPERATION_PAYUINILLEGAL = 'FailedOperation.PayUinIllegal'
 
+# Failed to exit the shared unit.
+FAILEDOPERATION_QUITSHAREUINT = 'FailedOperation.QuitShareUint'
+
 # Failed to leave the shared unit.
 FAILEDOPERATION_QUITSHAREUINTERROR = 'FailedOperation.QuitShareUintError'
 
+# Failed to exit the shared unit.
+FAILEDOPERATION_QUITESHAREUNIT = 'FailedOperation.QuiteShareUnit'
+
 # The invitation has already been sent before.
 FAILEDOPERATION_RESENTINVITATION = 'FailedOperation.ReSentInvitation'
 
+# Resources exceed the maximum upper limit.
+FAILEDOPERATION_RESOURCEOVERLIMIT = 'FailedOperation.ResourceOverLimit'
+
 # The permission authorization already exists.
 FAILEDOPERATION_ROLECONFIGURATIONAUTHORIZATIONALREADYEXIST = 'FailedOperation.RoleConfigurationAuthorizationAlreadyExist'
 
@@ -212,9 +305,30 @@ FAILEDOPERATION_SAMLSERVICEPROVIDERCREATEFAILED = 'FailedOperation.SAMLServicePr
 # The SAML identity provider information cannot be cleared when SSO is enabled.
 FAILEDOPERATION_SSOSTATUSENABLENOTCLEARIDENTITYPROVIDER = 'FailedOperation.SSoStatusEnableNotClearIdentityProvider'
 
+# Failed to generate the SCIM key.
+FAILEDOPERATION_SCIMCREDENTIALGENERATEERROR = 'FailedOperation.ScimCredentialGenerateError'
+
+# The shared region does not exist.
+FAILEDOPERATION_SHAREAREANOTEXIST = 'FailedOperation.ShareAreaNotExist'
+
+# The shared member does not exist.
+FAILEDOPERATION_SHAREMEMBERNOTEXIST = 'FailedOperation.ShareMemberNotExist'
+
 # The member is using a shared resource.
 FAILEDOPERATION_SHARERESOURCEMEMBERINUSE = 'FailedOperation.ShareResourceMemberInUse'
 
+# The shared resource does not exist.
+FAILEDOPERATION_SHARERESOURCENOTEXIST = 'FailedOperation.ShareResourceNotExist'
+
+# The shared resource type does not exist.
+FAILEDOPERATION_SHARERESOURCETYPENOTEXIST = 'FailedOperation.ShareResourceTypeNotExist'
+
+# Shared unit is not empty.
+FAILEDOPERATION_SHAREUNITNOTEMPTY = 'FailedOperation.ShareUnitNotEmpty'
+
+# The shared unit does not exist.
+FAILEDOPERATION_SHAREUNITNOTEXIST = 'FailedOperation.ShareUnitNotExist'
+
 # The UIN does not belong to the organization.
 FAILEDOPERATION_SOMEUINSNOTINORGANIZATION = 'FailedOperation.SomeUinsNotInOrganization'
 
@@ -287,9 +401,18 @@ INTERNALERROR = 'InternalError'
 # The parameter is incorrect.
 INVALIDPARAMETER = 'InvalidParameter'
 
+# The member in pay-on-behalf mode is not allowed to exit the organization voluntarily.
+INVALIDPARAMETER_ALLOWQUITILLEGAL = 'InvalidParameter.AllowQuitIllegal'
+
 # The permission configuration cannot be bound to this policy.
 INVALIDPARAMETER_BINDPOLICYNAMENOTALLOWED = 'InvalidParameter.BindPolicyNameNotAllowed'
 
+# Incorrect mobile phone verification code.
+INVALIDPARAMETER_CODEERROR = 'InvalidParameter.CodeError'
+
+# The mobile phone verification code has expired.
+INVALIDPARAMETER_CODEEXPIRED = 'InvalidParameter.CodeExpired'
+
 # The permission configuration name already exists.
 INVALIDPARAMETER_CONFIGURATIONNAMEALREADYEXISTS = 'InvalidParameter.ConfigurationNameAlreadyExists'
 
@@ -314,6 +437,9 @@ INVALIDPARAMETER_GROUPUSERALREADYEXISTS = 'InvalidParameter.GroupUserAlreadyExis
 # The user does not exist in the user group.
 INVALIDPARAMETER_GROUPUSERNOTEXIST = 'InvalidParameter.GroupUserNotExist'
 
+# The mailbox is invalid.
+INVALIDPARAMETER_INVALIDEMAIL = 'InvalidParameter.InvalidEmail'
+
 # Invalid nextToken.
 INVALIDPARAMETER_NEXTTOKENINVALID = 'InvalidParameter.NextTokenInvalid'
 
@@ -326,6 +452,9 @@ INVALIDPARAMETER_ORGANIZATIONNODENOTEXIST = 'InvalidParameter.OrganizationNodeNo
 # Parameter error.
 INVALIDPARAMETER_PARAMERROR = 'InvalidParameter.ParamError'
 
+# The password is invalid.
+INVALIDPARAMETER_PASSWORDILLEGAL = 'InvalidParameter.PasswordIllegal'
+
 # The custom policy content cannot be empty.
 INVALIDPARAMETER_POLICYDOCUMENTEMPTY = 'InvalidParameter.PolicyDocumentEmpty'
 
@@ -335,6 +464,9 @@ INVALIDPARAMETER_POLICYNAMEALREADYEXISTS = 'InvalidParameter.PolicyNameAlreadyEx
 # The policy name exceeds the length limit.
 INVALIDPARAMETER_POLICYNAMESIZEOVERUPPERLIMIT = 'InvalidParameter.PolicyNameSizeOverUpperLimit'
 
+# Errors occurred when the policy type is modified. Only custom policies can be modified.
+INVALIDPARAMETER_POLICYTYPEERROR = 'InvalidParameter.PolicyTypeError'
+
 # The permission configuration does not exist.
 INVALIDPARAMETER_ROLECONFIGURATIONNOTEXIST = 'InvalidParameter.RoleConfigurationNotExist'
 
@@ -344,12 +476,21 @@ INVALIDPARAMETER_ROLEPOLICYALREADYEXIST = 'InvalidParameter.RolePolicyAlreadyExi
 # The policy does not exist.
 INVALIDPARAMETER_ROLEPOLICYNOTEXIST = 'InvalidParameter.RolePolicyNotExist'
 
+# SCIM key does not exist.
+INVALIDPARAMETER_SCIMCREDENTIALNOTFOUND = 'InvalidParameter.ScimCredentialNotFound'
+
+# SCIM synchronization status error
+INVALIDPARAMETER_SCIMSYNCSTATUSERROR = 'InvalidParameter.ScimSyncStatusError'
+
 # Tag value error.
 INVALIDPARAMETER_TAGERROR = 'InvalidParameter.TagError'
 
 # The user still exists in the user group.
 INVALIDPARAMETER_USERALREADYEXISTSGROUP = 'InvalidParameter.UserAlreadyExistsGroup'
 
+# SCIM key status error
+INVALIDPARAMETER_USERSCIMCREDENTIALSTATUSERROR = 'InvalidParameter.UserScimCredentialStatusError'
+
 # The username already exists.
 INVALIDPARAMETER_USERNAMEALREADYEXISTS = 'InvalidParameter.UsernameAlreadyExists'
 
@@ -386,6 +527,12 @@ LIMITEXCEEDED_CREATEUSERLIMITEXCEEDED = 'LimitExceeded.CreateUserLimitExceeded'
 # Requests for creating user synchronization tasks exceed the limit.
 LIMITEXCEEDED_CREATEUSERSYNCPROVISIONINGLIMITEXCEEDED = 'LimitExceeded.CreateUserSyncProvisioningLimitExceeded'
 
+# The mailbox configuration exceeds the daily capacity limit.
+LIMITEXCEEDED_EMAILBINDOVERLIMIT = 'LimitExceeded.EmailBindOverLimit'
+
+# The number of organization identities exceeds limit.
+LIMITEXCEEDED_IDENTITYEXCEEDLIMIT = 'LimitExceeded.IdentityExceedLimit'
+
 # Invitation limit exceeded.
 LIMITEXCEEDED_INVITATIONOVERLIMIT = 'LimitExceeded.InvitationOverLimit'
 
@@ -398,9 +545,39 @@ LIMITEXCEEDED_NODEEXCEEDLIMIT = 'LimitExceeded.NodeExceedLimit'
 # The number of members exceeds the upper limit.
 LIMITEXCEEDED_ORGANIZATIONMEMBEROVERLIMIT = 'LimitExceeded.OrganizationMemberOverLimit'
 
+# The number of mobile phones exceeds the binding upper limit.
+LIMITEXCEEDED_PHONENUMBOUND = 'LimitExceeded.PhoneNumBound'
+
 # Requests for removing users from the user group exceed the limit.
 LIMITEXCEEDED_REMOVEUSERFROMGROUPLIMITEXCEEDED = 'LimitExceeded.RemoveUserFromGroupLimitExceeded'
 
+# The number of SCIM keys exceeds the limit.
+LIMITEXCEEDED_SCIMCREDENTIALLIMITEXCEEDED = 'LimitExceeded.ScimCredentialLimitExceeded'
+
+# The number of times to resend the activation email exceeds the limit.
+LIMITEXCEEDED_SENDEMAILLIMIT = 'LimitExceeded.SendEmailLimit'
+
+# The number of times to resend the activation email within one hour exceeds the limit.
+LIMITEXCEEDED_SENDEMAILWITHINONEHOURLIMIT = 'LimitExceeded.SendEmailWithinOneHourLimit'
+
+# The number of shared members for this operation exceeds the upper limit.
+LIMITEXCEEDED_SHAREUNITMEMBEROVERLIMIT = 'LimitExceeded.ShareUnitMemberOverLimit'
+
+# The number of shared resources for this operation exceeds the upper limit.
+LIMITEXCEEDED_SHAREUNITRESOURCEOVERLIMIT = 'LimitExceeded.ShareUnitResourceOverLimit'
+
+# The number of modifications to member binding information exceeds the limit.
+LIMITEXCEEDED_UPDATEEMAILBINDOVERLIMIT = 'LimitExceeded.UpdateEmailBindOverLimit'
+
+# Operation denied.
+OPERATIONDENIED = 'OperationDenied'
+
+# The resource does not exist.
+RESOURCENOTFOUND = 'ResourceNotFound'
+
+# The mailbox binding record does not exist.
+RESOURCENOTFOUND_EMAILBINDRECORDNOTEXIST = 'ResourceNotFound.EmailBindRecordNotExist'
+
 # The authorizable member identity does not exist.
 RESOURCENOTFOUND_MEMBERIDENTITYNOTEXIST = 'ResourceNotFound.MemberIdentityNotExist'
 
@@ -413,6 +590,9 @@ RESOURCENOTFOUND_MEMBERPOLICYNOTEXIST = 'ResourceNotFound.MemberPolicyNotExist'
 # The authentication subject does not exist.
 RESOURCENOTFOUND_ORGANIZATIONAUTHRELATIONNOTEXIST = 'ResourceNotFound.OrganizationAuthRelationNotExist'
 
+# Organization identity does not exist.
+RESOURCENOTFOUND_ORGANIZATIONIDENTITYNOTEXIST = 'ResourceNotFound.OrganizationIdentityNotExist'
+
 # The organization member does not exist.
 RESOURCENOTFOUND_ORGANIZATIONMEMBERNOTEXIST = 'ResourceNotFound.OrganizationMemberNotExist'
 
@@ -428,6 +608,9 @@ RESOURCENOTFOUND_ORGANIZATIONSERVICEASSIGNNOTEXIST = 'ResourceNotFound.Organizat
 # The organization service does not exist.
 RESOURCENOTFOUND_ORGANIZATIONSERVICENOTEXIST = 'ResourceNotFound.OrganizationServiceNotExist'
 
+# Policy does not exist.
+RESOURCENOTFOUND_POLICYNOTEXIST = 'ResourceNotFound.PolicyNotExist'
+
 # The permission authorization record does not exist.
 RESOURCENOTFOUND_ROLECONFIGURATIONAUTHORIZATIONNOTFOUND = 'ResourceNotFound.RoleConfigurationAuthorizationNotFound'
 
@@ -458,6 +641,9 @@ RESOURCENOTFOUND_USERPROVISIONINGTASKNOTFOUND = 'ResourceNotFound.UserProvisioni
 # The X509 certificate does not exist.
 RESOURCENOTFOUND_X509CERTIFICATENOTFOUND = 'ResourceNotFound.X509CertificateNotFound'
 
+# Resources are unavailable.
+RESOURCEUNAVAILABLE = 'ResourceUnavailable'
+
 # The operation is not supported.
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 
@@ -476,9 +662,18 @@ UNSUPPORTEDOPERATION_ADDDISCOUNTINHERITNOTALLOW = 'UnsupportedOperation.AddDisco
 # The resellers of the administrator and the member do not match.
 UNSUPPORTEDOPERATION_AGENTNOTSAME = 'UnsupportedOperation.AgentNotSame'
 
+# The created member is not allowed to create an organization.
+UNSUPPORTEDOPERATION_CREATEMEMBERNOTALLOWCREATEORGANIZATION = 'UnsupportedOperation.CreateMemberNotAllowCreateOrganization'
+
 # The created member cannot be removed from the organization.
 UNSUPPORTEDOPERATION_CREATEMEMBERNOTALLOWDELETE = 'UnsupportedOperation.CreateMemberNotAllowDelete'
 
+# The created member is not allowed to exit.
+UNSUPPORTEDOPERATION_CREATEMEMBERNOTALLOWQUIT = 'UnsupportedOperation.CreateMemberNotAllowQuit'
+
+# Deleting the payment relationship is not allowed.
+UNSUPPORTEDOPERATION_DELETEDELEGATEPAYERNOTALLOW = 'UnsupportedOperation.DeleteDelegatePayerNotAllow'
+
 # Payment-on-behalf is not supported for this member or payer as it is a reseller.
 UNSUPPORTEDOPERATION_EXISTEDAGENT = 'UnsupportedOperation.ExistedAgent'
 
@@ -518,6 +713,12 @@ UNSUPPORTEDOPERATION_MEMBERISNOTCLIENT = 'UnsupportedOperation.MemberIsNotClient
 # No credit card is bound to the member.
 UNSUPPORTEDOPERATION_MEMBERNOPAYMENT = 'UnsupportedOperation.MemberNoPayment'
 
+# The member does not support voluntary exit.
+UNSUPPORTEDOPERATION_MEMBERNOTALLOWQUIT = 'UnsupportedOperation.MemberNotAllowQuit'
+
+# The member does not support the operation.
+UNSUPPORTEDOPERATION_MEMBERUNSUPPORTEDOPERATION = 'UnsupportedOperation.MemberUnsupportedOperation'
+
 # There is an ongoing order.
 UNSUPPORTEDOPERATION_ORDERINPROGRESSEXISTED = 'UnsupportedOperation.OrderInProgressExisted'
 
@@ -532,3 +733,6 @@ UNSUPPORTEDOPERATION_PAYEREXISTACCOUNTLEVELDISCOUNTINHERIT = 'UnsupportedOperati
 
 # Pay-on-behalf is not supported for second-level reseller customers exist.
 UNSUPPORTEDOPERATION_SECONDARYDISTRIBUTORSUBCLIENTEXISTED = 'UnsupportedOperation.SecondaryDistributorSubClientExisted'
+
+# Sharing with other organizational members is not supported.
+UNSUPPORTEDOPERATION_SHARINGTOOTHERORGANIZATIONMEMBER = 'UnsupportedOperation.SharingToOtherOrganizationMember'
