@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -38,5 +38,8 @@ INVALIDPARAMETERVALUE_ERRTEXTCONTENTLEN = 'InvalidParameterValue.ErrTextContentL
 # The text in the request is in the incorrect format (base64-encoded text is required).
 INVALIDPARAMETERVALUE_ERRTEXTCONTENTTYPE = 'InvalidParameterValue.ErrTextContentType'
 
+# 
+REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'
+
 # Operation not authorized/No valid package/The account is overdue
 UNAUTHORIZEDOPERATION_UNAUTHORIZED = 'UnauthorizedOperation.Unauthorized'
