@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -64,6 +64,9 @@ Note: This field may return null, indicating that no valid values can be obtaine
 
     @property
     def Label(self):
+        """Result of the moderation. <br>`Normal`: normal content; `Porn`: pornographic content; `Abuse`: abusive content; **Ad**: advertising content; `Custom`: custom violating content
+        :rtype: str
+        """
         return self._Label
 
     @Label.setter
@@ -72,6 +75,10 @@ Note: This field may return null, indicating that no valid values can be obtaine
 
     @property
     def Suggestion(self):
+        """Recommended follow-up action. <br>`Block`: block it automatically; `Review`: review the content again in human; **Pass**: pass
+Note: This field may return `null`, indicating that no valid value can be found.
+        :rtype: str
+        """
         return self._Suggestion
 
     @Suggestion.setter
@@ -80,6 +87,10 @@ Note: This field may return null, indicating that no valid values can be obtaine
 
     @property
     def Keywords(self):
+        """Returns the information of keywords hit in the text. When no value is returned and `Score` is not empty, it means the `Label` is determined by the semantic-based detection model.
+Note: This field may return null, indicating that no valid values can be obtained.
+        :rtype: list of str
+        """
         return self._Keywords
 
     @Keywords.setter
@@ -88,6 +99,10 @@ Note: This field may return null, indicating that no valid values can be obtaine
 
     @property
     def Score(self):
+        """This field indicates the convincing level of the `Label`, ranging from `0` (lowest) to `100` (highest). 
+Note: This field may return `null`, indicating that no valid value can be found.
+        :rtype: int
+        """
         return self._Score
 
     @Score.setter
@@ -96,6 +111,10 @@ Note: This field may return null, indicating that no valid values can be obtaine
 
     @property
     def LibType(self):
+        """It indicates the library type corresponding with the keyword. Valid values: `1` (blocklist/allowlist library) and `2` (custom keyword library). If no custom keyword library is configured, the default value is 1.
+Note: This field may return `null`, indicating that no valid value can be found.
+        :rtype: int
+        """
         return self._LibType
 
     @LibType.setter
@@ -104,6 +123,10 @@ Note: This field may return null, indicating that no valid values can be obtaine
 
     @property
     def LibId(self):
+        """This field is **only valid when `Label` is `Custom`. It returns the custom library ID to facilitate the library management and configuration.
+Note: This field may return `null`, indicating that no valid value can be found.
+        :rtype: str
+        """
         return self._LibId
 
     @LibId.setter
@@ -112,6 +135,10 @@ Note: This field may return null, indicating that no valid values can be obtaine
 
     @property
     def LibName(self):
+        """This field is **only valid when `Label` is `Custom` (custom keyword)`. It returns the custom library name to facilitate the library management and configuration.
+Note: This field may return `null`, indicating that no valid value can be found.
+        :rtype: str
+        """
         return self._LibName
 
     @LibName.setter
@@ -120,6 +147,10 @@ Note: This field may return null, indicating that no valid values can be obtaine
 
     @property
     def SubLabel(self):
+        """The field returns the second-level labels under the current label.
+Note: This field may return `null`, indicating that no valid value can be found.
+        :rtype: str
+        """
         return self._SubLabel
 
     @SubLabel.setter
@@ -128,6 +159,10 @@ Note: This field may return null, indicating that no valid values can be obtaine
 
     @property
     def Tags(self):
+        """Returns the keywords, label, sub-label and the score.
+Note: This field may return null, indicating that no valid values can be obtained.
+        :rtype: list of Tag
+        """
         return self._Tags
 
     @Tags.setter
@@ -194,6 +229,10 @@ Note: Since the iOS14 update in 2021, Apple Inc. has allowed users to manually a
 
     @property
     def IP(self):
+        """This field indicates the IP address of the device used by the service subscriber. <br>
+Note: Currently, only IPv4 addresses can be recorded.
+        :rtype: str
+        """
         return self._IP
 
     @IP.setter
@@ -202,6 +241,9 @@ Note: Since the iOS14 update in 2021, Apple Inc. has allowed users to manually a
 
     @property
     def Mac(self):
+        """This field indicates the MAC address used by the service subscriber to facilitate device identification and management. Its format and value are consistent with those of the standard MAC address.
+        :rtype: str
+        """
         return self._Mac
 
     @Mac.setter
@@ -210,6 +252,9 @@ Note: Since the iOS14 update in 2021, Apple Inc. has allowed users to manually a
 
     @property
     def TokenId(self):
+        """* In beta test. Available soon.*
+        :rtype: str
+        """
         return self._TokenId
 
     @TokenId.setter
@@ -218,6 +263,9 @@ Note: Since the iOS14 update in 2021, Apple Inc. has allowed users to manually a
 
     @property
     def DeviceId(self):
+        """* In beta test. Available soon.*
+        :rtype: str
+        """
         return self._DeviceId
 
     @DeviceId.setter
@@ -226,6 +274,9 @@ Note: Since the iOS14 update in 2021, Apple Inc. has allowed users to manually a
 
     @property
     def IMEI(self):
+        """This field represents the **IMEI** (International Mobile Equipment Identity) number of the device used by the service subscriber. IMEI can be used to identify each independent mobile communication device, such as a mobile phone, which is convenient for device identification and management. <br>Note: IMEI is formatted with **15 to 17 numbers only**.
+        :rtype: str
+        """
         return self._IMEI
 
     @IMEI.setter
@@ -234,6 +285,10 @@ Note: Since the iOS14 update in 2021, Apple Inc. has allowed users to manually a
 
     @property
     def IDFA(self):
+        """**Dedicated for iOS device**. This field indicates the **IDFA** (Identifier for Advertising) corresponding to the service subscriber. IDFA, a string of hexadecimal 32 characters including numbers and letters, is provided by Apple Inc. to identify the user.<br>
+Note: Since the iOS14 update in 2021, Apple Inc. has allowed users to manually activate or deactivate IDFA, so the validity of the string identifier may be reduced.
+        :rtype: str
+        """
         return self._IDFA
 
     @IDFA.setter
@@ -242,6 +297,9 @@ Note: Since the iOS14 update in 2021, Apple Inc. has allowed users to manually a
 
     @property
     def IDFV(self):
+        """**Dedicated for iOS device**. This field indicates the **IDFV** (Identifier for Vendor) corresponding to the service subscriber. IDFV, a string of hexadecimal 32 characters including numbers and letters, is provided by Apple Inc. to identify the vendor. IDFV can also be used as a unique device identifier.
+        :rtype: str
+        """
         return self._IDFV
 
     @IDFV.setter
@@ -284,6 +342,9 @@ class RiskDetails(AbstractModel):
 
     @property
     def Label(self):
+        """This field returns the risk categories after account information detection. Valid values: **RiskAccount** (the account is at risk), **RiskIP** (the IP address is at risk), and **RiskIMEI** (the mobile device identifier is at risk).
+        :rtype: str
+        """
         return self._Label
 
     @Label.setter
@@ -292,6 +353,9 @@ class RiskDetails(AbstractModel):
 
     @property
     def Level(self):
+        """This field returns the risk levels after account information detection. Valid values: **1** (suspected to be at risk) and **2** (malicious risk).
+        :rtype: int
+        """
         return self._Level
 
     @Level.setter
@@ -312,6 +376,155 @@ class RiskDetails(AbstractModel):
         
 
 
+class SentimentAnalysis(AbstractModel):
+    """
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _Label: 
+        :type Label: str
+        :param _Score: 
+        :type Score: int
+        :param _Detail: 
+        :type Detail: :class:`tencentcloud.tms.v20201229.models.SentimentDetail`
+        :param _Code: 
+        :type Code: str
+        :param _Message: 
+        :type Message: str
+        """
+        self._Label = None
+        self._Score = None
+        self._Detail = None
+        self._Code = None
+        self._Message = None
+
+    @property
+    def Label(self):
+        """
+        :rtype: str
+        """
+        return self._Label
+
+    @Label.setter
+    def Label(self, Label):
+        self._Label = Label
+
+    @property
+    def Score(self):
+        """
+        :rtype: int
+        """
+        return self._Score
+
+    @Score.setter
+    def Score(self, Score):
+        self._Score = Score
+
+    @property
+    def Detail(self):
+        """
+        :rtype: :class:`tencentcloud.tms.v20201229.models.SentimentDetail`
+        """
+        return self._Detail
+
+    @Detail.setter
+    def Detail(self, Detail):
+        self._Detail = Detail
+
+    @property
+    def Code(self):
+        """
+        :rtype: str
+        """
+        return self._Code
+
+    @Code.setter
+    def Code(self, Code):
+        self._Code = Code
+
+    @property
+    def Message(self):
+        """
+        :rtype: str
+        """
+        return self._Message
+
+    @Message.setter
+    def Message(self, Message):
+        self._Message = Message
+
+
+    def _deserialize(self, params):
+        self._Label = params.get("Label")
+        self._Score = params.get("Score")
+        if params.get("Detail") is not None:
+            self._Detail = SentimentDetail()
+            self._Detail._deserialize(params.get("Detail"))
+        self._Code = params.get("Code")
+        self._Message = params.get("Message")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class SentimentDetail(AbstractModel):
+    """
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _Positive: 
+        :type Positive: int
+        :param _Negative: 
+        :type Negative: int
+        """
+        self._Positive = None
+        self._Negative = None
+
+    @property
+    def Positive(self):
+        """
+        :rtype: int
+        """
+        return self._Positive
+
+    @Positive.setter
+    def Positive(self, Positive):
+        self._Positive = Positive
+
+    @property
+    def Negative(self):
+        """
+        :rtype: int
+        """
+        return self._Negative
+
+    @Negative.setter
+    def Negative(self, Negative):
+        self._Negative = Negative
+
+
+    def _deserialize(self, params):
+        self._Positive = params.get("Positive")
+        self._Negative = params.get("Negative")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class Tag(AbstractModel):
     """Returns the keywords, label, sub-label and the score.
 
@@ -335,6 +548,10 @@ Note: This field may return null, indicating that no valid values can be obtaine
 
     @property
     def Keyword(self):
+        """Returns the hit keywords.
+Note: This field may return null, indicating that no valid values can be obtained.
+        :rtype: str
+        """
         return self._Keyword
 
     @Keyword.setter
@@ -343,6 +560,10 @@ Note: This field may return null, indicating that no valid values can be obtaine
 
     @property
     def SubLabel(self):
+        """Returns the sub-tags.
+Note: This field may return null, indicating that no valid values can be obtained.
+        :rtype: str
+        """
         return self._SubLabel
 
     @SubLabel.setter
@@ -351,6 +572,10 @@ Note: This field may return null, indicating that no valid values can be obtaine
 
     @property
     def Score(self):
+        """Returns the score for the sub-label
+Note: This field may return null, indicating that no valid values can be obtained.
+        :rtype: int
+        """
         return self._Score
 
     @Score.setter
@@ -389,15 +614,21 @@ class TextModerationRequest(AbstractModel):
         :type User: :class:`tencentcloud.tms.v20201229.models.User`
         :param _Device: This field indicates the device information related with the object to be moderated, which can be used to identify violating devices at risk.
         :type Device: :class:`tencentcloud.tms.v20201229.models.Device`
+        :param _SourceLanguage: This field Indicates the original language of the content.The enumeration values are ("en", "zh", ""), where en means English, zh means Chinese, and an empty string means the default language is Chinese. It is recommended to enter "en" only when the language of the content is clearly "English".
+        :type SourceLanguage: str
         """
         self._Content = None
         self._BizType = None
         self._DataId = None
         self._User = None
         self._Device = None
+        self._SourceLanguage = None
 
     @property
     def Content(self):
+        """This field indicates the text content of the object to be moderated. The text needs to be encoded in utf-8 format and encrypted with Base64. It can contain up to 10,000 characters, calculated by unicode encoding.
+        :rtype: str
+        """
         return self._Content
 
     @Content.setter
@@ -406,6 +637,9 @@ class TextModerationRequest(AbstractModel):
 
     @property
     def BizType(self):
+        """This field indicates the specific policy number, which is used for the API call and can be configured in the CMS console. If it's not entered (left empty), the default moderation policy is adopted. If it's entered, the moderation policies are specified for business scenarios. <br>Note: Biztype contains 3 to 32 characters, including numbers, letters and underscores only. Different Biztypes are associated with different business scenarios and moderation policies. Ensure that you use the Biztype corresponding to the policy you want to apply.
+        :rtype: str
+        """
         return self._BizType
 
     @BizType.setter
@@ -414,6 +648,9 @@ class TextModerationRequest(AbstractModel):
 
     @property
     def DataId(self):
+        """This field indicates the data ID you assigned to the object to be moderated, which is convenient for you to identify and manage the file. <br>Value: this field can contain **up to 64 characters**, including uppercase and lowercase letters, numbers and four special symbols (_, -, @, #)
+        :rtype: str
+        """
         return self._DataId
 
     @DataId.setter
@@ -422,6 +659,9 @@ class TextModerationRequest(AbstractModel):
 
     @property
     def User(self):
+        """This field indicates the user information related with the object to be moderated, which can be used to identify violating users at risk.
+        :rtype: :class:`tencentcloud.tms.v20201229.models.User`
+        """
         return self._User
 
     @User.setter
@@ -430,12 +670,26 @@ class TextModerationRequest(AbstractModel):
 
     @property
     def Device(self):
+        """This field indicates the device information related with the object to be moderated, which can be used to identify violating devices at risk.
+        :rtype: :class:`tencentcloud.tms.v20201229.models.Device`
+        """
         return self._Device
 
     @Device.setter
     def Device(self, Device):
         self._Device = Device
 
+    @property
+    def SourceLanguage(self):
+        """This field Indicates the original language of the content.The enumeration values are ("en", "zh", ""), where en means English, zh means Chinese, and an empty string means the default language is Chinese. It is recommended to enter "en" only when the language of the content is clearly "English".
+        :rtype: str
+        """
+        return self._SourceLanguage
+
+    @SourceLanguage.setter
+    def SourceLanguage(self, SourceLanguage):
+        self._SourceLanguage = SourceLanguage
+
 
     def _deserialize(self, params):
         self._Content = params.get("Content")
@@ -447,6 +701,7 @@ class TextModerationRequest(AbstractModel):
         if params.get("Device") is not None:
             self._Device = Device()
             self._Device._deserialize(params.get("Device"))
+        self._SourceLanguage = params.get("SourceLanguage")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
@@ -493,7 +748,9 @@ Note: This field may return `null`, indicating that no valid value can be found.
         :param _ContextText: Returns the context text.
 Note: This field may return null, indicating that no valid values can be obtained.
         :type ContextText: str
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _SentimentAnalysis: 
+        :type SentimentAnalysis: :class:`tencentcloud.tms.v20201229.models.SentimentAnalysis`
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._BizType = None
@@ -507,10 +764,14 @@ Note: This field may return null, indicating that no valid values can be obtaine
         self._DataId = None
         self._SubLabel = None
         self._ContextText = None
+        self._SentimentAnalysis = None
         self._RequestId = None
 
     @property
     def BizType(self):
+        """This field returns the BizType of the request parameters
+        :rtype: str
+        """
         return self._BizType
 
     @BizType.setter
@@ -519,6 +780,9 @@ Note: This field may return null, indicating that no valid values can be obtaine
 
     @property
     def Label(self):
+        """This field returns the **negative label with the highest priority** in the moderation results (DetailResults), which indicates the moderation result recommended by the model. It is recommended that you handle different violations with the suggested values according to your business needs. <br>Returned values: **Normal**: normal content; **Porn**: pornographic content; **Abuse**: abusive content; **Ad**: advertising content; **Custom**: custom violating content, and others such as objectionable, insecure or inappropriate content.
+        :rtype: str
+        """
         return self._Label
 
     @Label.setter
@@ -527,6 +791,9 @@ Note: This field may return null, indicating that no valid values can be obtaine
 
     @property
     def Suggestion(self):
+        """This field returns the follow-up moderation suggestions. The returned value indicates the recommended operation after obtaining the moderation result. It is recommended that you handle different violations with the suggested values according to your business needs. <br>Returned values: **Block**: block; **Review**: human moderation; **Pass**: pass
+        :rtype: str
+        """
         return self._Suggestion
 
     @Suggestion.setter
@@ -535,6 +802,10 @@ Note: This field may return null, indicating that no valid values can be obtaine
 
     @property
     def Keywords(self):
+        """This field returns the keywords matched with the libraries in the moderated text under the current label to mark the specific violations (for example, *Friend me*). This parameter may have multiple returned values, indicating multiple keywords are matched. If the returned value is empty and the `Score` is not empty, it means that the negative label corresponding to the moderation result is a value returned from the semantic model judgment
+Note: This field may return `null`, indicating that no valid value can be found.
+        :rtype: list of str
+        """
         return self._Keywords
 
     @Keywords.setter
@@ -543,6 +814,9 @@ Note: This field may return null, indicating that no valid values can be obtaine
 
     @property
     def Score(self):
+        """This field returns the confidence level under the current label. Value range: 0 (**the lowest confidence level**) - 100 (**the highest confidence level**). The higher the value, the more likely the text is to belong to the category indicated by the current label. For example, *pornographic 99* indicates that the text is very likely to be pornographic, and *pornographic 0* indicates that the text is not pornographic
+        :rtype: int
+        """
         return self._Score
 
     @Score.setter
@@ -551,6 +825,10 @@ Note: This field may return null, indicating that no valid values can be obtaine
 
     @property
     def DetailResults(self):
+        """This field returns the moderation results based on the text libraries. For details, see `DetailResults` in the data structure
+Note: This field may return `null`, indicating that no valid value can be found.
+        :rtype: list of DetailResults
+        """
         return self._DetailResults
 
     @DetailResults.setter
@@ -559,6 +837,10 @@ Note: This field may return null, indicating that no valid values can be obtaine
 
     @property
     def RiskDetails(self):
+        """This field returns the detection results of violating accounts at risk, mainly including violation categories and risk levels. For details, see `RiskDetails` in the data structure
+Note: This field may return `null`, indicating that no valid value can be found.
+        :rtype: list of RiskDetails
+        """
         return self._RiskDetails
 
     @RiskDetails.setter
@@ -567,6 +849,10 @@ Note: This field may return null, indicating that no valid values can be obtaine
 
     @property
     def Extra(self):
+        """This field returns the extra information configured according to your needs. If it's not configured, the returned value is empty by default. <br>Note: the returned information varies based on different customers or Biztypes. If you need to configure this field, please submit a ticket or contact after-sales manager
+Note: This field may return `null`, indicating that no valid value can be found.
+        :rtype: str
+        """
         return self._Extra
 
     @Extra.setter
@@ -575,6 +861,10 @@ Note: This field may return null, indicating that no valid values can be obtaine
 
     @property
     def DataId(self):
+        """This field returns the `DataId` in the request parameter corresponding to the moderated object
+Note: This field may return `null`, indicating that no valid value can be found.
+        :rtype: str
+        """
         return self._DataId
 
     @DataId.setter
@@ -583,6 +873,10 @@ Note: This field may return null, indicating that no valid values can be obtaine
 
     @property
     def SubLabel(self):
+        """The field returns the second-level labels under the current label.
+Note: This field may return `null`, indicating that no valid value can be found.
+        :rtype: str
+        """
         return self._SubLabel
 
     @SubLabel.setter
@@ -591,14 +885,32 @@ Note: This field may return null, indicating that no valid values can be obtaine
 
     @property
     def ContextText(self):
+        """Returns the context text.
+Note: This field may return null, indicating that no valid values can be obtained.
+        :rtype: str
+        """
         return self._ContextText
 
     @ContextText.setter
     def ContextText(self, ContextText):
         self._ContextText = ContextText
 
+    @property
+    def SentimentAnalysis(self):
+        """
+        :rtype: :class:`tencentcloud.tms.v20201229.models.SentimentAnalysis`
+        """
+        return self._SentimentAnalysis
+
+    @SentimentAnalysis.setter
+    def SentimentAnalysis(self, SentimentAnalysis):
+        self._SentimentAnalysis = SentimentAnalysis
+
     @property
     def RequestId(self):
+        """The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -628,6 +940,9 @@ Note: This field may return null, indicating that no valid values can be obtaine
         self._DataId = params.get("DataId")
         self._SubLabel = params.get("SubLabel")
         self._ContextText = params.get("ContextText")
+        if params.get("SentimentAnalysis") is not None:
+            self._SentimentAnalysis = SentimentAnalysis()
+            self._SentimentAnalysis._deserialize(params.get("SentimentAnalysis"))
         self._RequestId = params.get("RequestId")
 
 
@@ -684,6 +999,9 @@ Note: Up to 5 MB is supported, and the minimum resolution is 256 x 256. When it
 
     @property
     def UserId(self):
+        """This field indicates the service subscriber ID. This ID can be used to optimize the moderation result judgment based on the account's violation records, which is helpful for auxiliary judgment when there is a risk of suspected violations.
+        :rtype: str
+        """
         return self._UserId
 
     @UserId.setter
@@ -692,6 +1010,9 @@ Note: Up to 5 MB is supported, and the minimum resolution is 256 x 256. When it
 
     @property
     def Nickname(self):
+        """This field indicates the account nickname information of the service subscriber.
+        :rtype: str
+        """
         return self._Nickname
 
     @Nickname.setter
@@ -700,6 +1021,10 @@ Note: Up to 5 MB is supported, and the minimum resolution is 256 x 256. When it
 
     @property
     def AccountType(self):
+        """This field indicates the account type corresponding to the service subscriber ID.<br>
+Use this field and the account ID (UserId) together to determine a unique account.
+        :rtype: int
+        """
         return self._AccountType
 
     @AccountType.setter
@@ -708,6 +1033,10 @@ Note: Up to 5 MB is supported, and the minimum resolution is 256 x 256. When it
 
     @property
     def Gender(self):
+        """This field indicates the gender information of the service subscriber's account.<br>
+Values: **0** (default value, indicating the gender is unknown), **1** (male) and **2** (female).
+        :rtype: int
+        """
         return self._Gender
 
     @Gender.setter
@@ -716,6 +1045,10 @@ Note: Up to 5 MB is supported, and the minimum resolution is 256 x 256. When it
 
     @property
     def Age(self):
+        """This field indicates the age information of the service subscriber's account.<br>
+Values: Integers between **0** (default value, indicating that the age is unknown) and the number of (**custom maximum age**).
+        :rtype: int
+        """
         return self._Age
 
     @Age.setter
@@ -724,6 +1057,10 @@ Note: Up to 5 MB is supported, and the minimum resolution is 256 x 256. When it
 
     @property
     def Level(self):
+        """This field indicates the level information of the service subscriber's account.<br>
+Values: **0** (default value, indicating that the level is unknown), **1** (lower level), **2** (medium level) and **3** (higher level). Currently, **custom levels are not supported**.
+        :rtype: int
+        """
         return self._Level
 
     @Level.setter
@@ -732,6 +1069,10 @@ Note: Up to 5 MB is supported, and the minimum resolution is 256 x 256. When it
 
     @property
     def Phone(self):
+        """This field indicates the mobile phone number information of the service subscriber's account. The mobile phone numbers in various regions of the world can be recorded.<br>
+Note: Please keep the format of mobile phone number uniform. For example, uniformly use the area code format (086/+86), etc.
+        :rtype: str
+        """
         return self._Phone
 
     @Phone.setter
@@ -740,6 +1081,10 @@ Note: Up to 5 MB is supported, and the minimum resolution is 256 x 256. When it
 
     @property
     def HeadUrl(self):
+        """This field indicates the URL of the service subscriber's profile photos formatted with .png, .jpg, .jpeg, .bmp, .gif and .webp.
+Note: Up to 5 MB is supported, and the minimum resolution is 256 x 256. When it takes more than 3 seconds to download, the "download timeout" is returned.
+        :rtype: str
+        """
         return self._HeadUrl
 
     @HeadUrl.setter
@@ -748,6 +1093,9 @@ Note: Up to 5 MB is supported, and the minimum resolution is 256 x 256. When it
 
     @property
     def Desc(self):
+        """This field indicates the profile information of service subscribers. It can contain up to 5,000 characters, including Chinese characters, letters and special symbols.
+        :rtype: str
+        """
         return self._Desc
 
     @Desc.setter
@@ -756,6 +1104,9 @@ Note: Up to 5 MB is supported, and the minimum resolution is 256 x 256. When it
 
     @property
     def RoomId(self):
+        """Room ID of the group chat.
+        :rtype: str
+        """
         return self._RoomId
 
     @RoomId.setter
@@ -764,6 +1115,9 @@ Note: Up to 5 MB is supported, and the minimum resolution is 256 x 256. When it
 
     @property
     def ReceiverId(self):
+        """Receiver ID.
+        :rtype: str
+        """
         return self._ReceiverId
 
     @ReceiverId.setter
@@ -772,6 +1126,9 @@ Note: Up to 5 MB is supported, and the minimum resolution is 256 x 256. When it
 
     @property
     def SendTime(self):
+        """Generation time of the message, in ms.
+        :rtype: int
+        """
         return self._SendTime
 
     @SendTime.setter
